<?php
$lang['invalidemail'] = 'The email address entered is invalid';
$lang['empty_query'] = 'Empty query?? %s';
$lang['no_db_driver'] = 'No compatible database drivers found';
$lang['test_check_output_buffering'] = 'Tikrinimo rezultatų kaupimas';
$lang['test_check_output_buffering_failed'] = 'Tikrinimo rezultatų kaupimas i&scaron;jungtas. Jūs tikriausiai negalėsite naudoti bet kurią i&scaron; funkcijų, kuriomis reikalauja kaupimo';
$lang['phpinfo'] = 'Rodyti PHP Informatcija';
$lang['mod_security'] = 'Apache Mod Security';
$lang['test_check_tempnam'] = 'Tikrinama for tempnam Function';
$lang['test_check_db_drivers'] = 'DB drivers';
$lang['test_check_db_drivers_failed'] = 'Nerasta DB drivers';
$lang['test_check_register_globals'] = 'Tikrinama PHP register globals';
$lang['test_check_register_globals_failed'] = 'PHP register globals aktyvu. Saugumo sumetimais rekomenduojame i&scaron;jungti.';
$lang['test_check_disable_functions'] = 'Tikrinama PHP disable funkcijos';
$lang['test_check_disable_functions_failed'] = 'Įspėjimas: &scaron;ios funkcijos jūsų serveryje i&scaron;jungtos';
$lang['install_admin_db_port'] = 'Duomenų bazės jungtis';
$lang['install_admin_db_port_info'] = 'Jei nežinote palikite tusčia';
$lang['install_admin_db_socket'] = 'Duomenų bazės lizdas';
$lang['install_admin_db_socket_info'] = 'NEPALAIKOMA.';
$lang['install_admin_frontendlang'] = 'Numatyta prie&scaron;akinė kalba. Tai nustatys kokia lokalią naudoti datos formavimui ir pan..';
$lang['install_default_encoding'] = 'Dažniausiai, default_encoding turėtų būt utf-8.';
$lang['installer_done'] = '[atlikta]';
$lang['installer_failed'] = '[nepavyko]';
$lang['create_permission'] = 'Sukurti leidimus ...';
$lang['add_column_sql'] = 'Pridedamas stulpelis %s lentelėje...';
$lang['update_table_sql'] = 'Atnaujinama lentelė %s ...';
$lang['installing_module'] = 'Įdiegiamas modulis %s ...';
$lang['updating_schema_version'] = 'Atnaujinama versijos schema %s ...';
$lang['upgrade_config'] = 'Atnaujinamas config.php';
$lang['upgrade_config_info'] = 'config atnaujinata';
$lang['upgrade_failed_again'] = 'Vienas ar keli atnaujinimai nepavyko. Pra&scaron;ome i&scaron;taisyti problemas ir paspausti mygtuką esantį žemiau.';
$lang['upgrade_cache_dirs'] = 'Valomas direktorijų ke&scaron;as';
$lang['cannot_clean_cache_dirs'] = 'Ke&scaron;o valymas nepavyko!';
$lang['upgrade_schema'] = 'Atnaujinta schema';
$lang['need_upgrade_schema'] = 'Reikia atnaujinti CMS.<br />Jūs naudojatės  %s schemos versija, o jums reikia atnaujinti iki %s';
$lang['schema_ok'] = 'CMS duomenų bazė galioja.  Naudojama %s schemos versija.';
$lang['noneed_upgrade_schema'] = 'CMS duomenų bazė galioja.  Naudojama %s schemos versija.';
$lang['upgrade_modules'] = 'Atnaujinti moduliai';
$lang['noneed_upgrade_modules'] = '&Scaron;erdies moduliai galiuoja';
$lang['upgrade_sql_module_from_to'] = 'Atnaujinama SQL &quot;%s&quot; modulis i&scaron; %s į %s ...';
$lang['upgrade_event_module_from_to'] = 'Atnaujimamas Įvykis &quot;%s&quot; modulis i&scaron; %s į %s ...';
$lang['sitedown_not_removed'] = 'Nepavyko pa&scaron;alinti tmp/cache/SITEDOWN file. Pra&scaron;ome pa&scaron;alinti rankiniu būdu, kitaip jūsų svetainė rodys tvarkymo žinutę.';
$lang['upgrade_ok'] = 'Pra&scaron;ome peržiūrėti config.php, pakeisite naujas nuostatas ir atsatykite leidimus į normalią būseną. Taip pat turėtumėte patikrinti ar visi moduliai galioja.  ';
$lang['upgrade_complete'] = 'Atnaujinimo procesas baigtas';
$lang['upgrade_end'] = 'CMS naujausias. Prežiūrėkite %s  ar %s.';
$lang['here'] = 'svetainę';
$lang['go_to_admin'] = 'administravimą';
$lang['errorfilenot'] = 'Byla nerasta!';
$lang['errorfilenotwritable'] = 'Byla neįra&scaron;oma!';
$lang['nofiles'] = '&Scaron;is &scaron;altinis neegzistuoja!';
$lang['is_directory'] = 'Direktorija tusčia!';
$lang['is_readable_false'] = '&Scaron;altinis neperskaitomas!';
$lang['checksum_match'] = 'Checksum sutampa!';
$lang['checksum_not_match'] = 'Checksum nesutampa!';
$lang['not_checksum'] = 'Neįmanoma peržvelgti checksum!';
$lang['format_datetime'] = '%c';
$lang['upload_err_ini_size'] = 'Atsiųsta byla vir&scaron;yja upload_max_filesize nurodyta php.ini!';
$lang['upload_err_form_size'] = 'Atsiųsta byla vir&scaron;yja MAX_FILE_SIZE kuris nurodytas HTML formoje.';
$lang['upload_err_partial'] = 'Atsiųsta byla buvo tik i&scaron;dalies.';
$lang['upload_err_no_file'] = 'Byla nebuvo atsiųsta.';
$lang['upload_err_no_tmp_dir'] = 'Nerandama laikina direktorija.';
$lang['upload_err_cant_write'] = 'Nepavyko įra&scaron;yti į diską.';
$lang['upload_err_extension'] = 'Bylos siuntimas buvo nutrauktas dėl plėtinio.';
$lang['upload_err_empty'] = 'Bylos dydis nulis';
$lang['upload_err_unknown'] = 'Nežinoma bylos atsiuntimo problema';
$lang['function_file_uploads_off'] = 'file_uploads yra i&scaron;jungtas jūsų php konfiguracijoje.';
$lang['upload_file_no_readable'] = 'Atsiųsta byla neperskaitoma';
$lang['upload_file_multiple'] = 'Dauginis bylų atsiuntimas negalimas!';
$lang['test_check_magic_quotes_gpc'] = 'Magic quotes for Get/Post/Cookie operations';
$lang['test_check_magic_quotes_gpc_failed'] = 'When magic_quotes are on, all single-quote, double quote and backslash are escaped with a backslash automatically. This can cause many problems in CMS.';
$lang['test_check_magic_quotes_runtime'] = 'Magic quotes in runtime';
$lang['test_check_magic_quotes_runtime_failed'] = 'When magic_quotes are on, most functions that return data from any sort of external source including databases and text files will have quotes escaped with a backslash. This will cause problems with CMS made simple.';
$lang['install_admin_checksum'] = 'Patikrinti įdiegimą';
$lang['upgrade_admin_checksum'] = 'Patikrinti sistemos atnaujinimus';
$lang['checksum'] = 'Checksum testas';
$lang['checksum_file'] = 'Checksum byla';
$lang['install_test_checksum'] = 'Jūs galite patikrinti  bylų suderinamumą pagal originalų CMS checksum. Tai gali pad4t i6siai6kinti atsiuntimo problemas.';
$lang['checksum_passed'] = 'Visi checksums sutampa!';
$lang['checksum_failed'] = 'Checksum sutampa bet  su klaidomis. Daugiau informacijos ie&scaron;kokite pagalbos skiltyje.';
$lang['test_check_open_basedir'] = 'Tikrinama PHP Open Basedir';
$lang['test_check_open_basedir_failed'] = 'Open basedir restrictions are in effect. You may have difficulty with some addon functionality with this restriction.';
$lang['unlimited'] = 'Neribota';
$lang['test_open_basedir_session_save_path'] = 'Open basedir restrictions appear to be in effect. If you have SESSION problems and ini_set works, you can try to enable session by cookies adding: ini_set(&#039;session.use_only_cookies&#039;, 1);  to top of include.php';
$lang['install_warn_db_createtables'] = 'Normally this field should be checked at all times.  Use caution when disabling this feature';
$lang['install_admin_tablesnotcreated'] = 'Process complete.  The installation process has completed, at your request database tables were not created.  However, the config file has been reset and all pre-installation tests have passed.  Thank you, and here is your';
$lang['info_create_dir_and_file'] = 'The HTTP Process owner cannot create a file inside a directory that it owns. This probably means that safe mode is enabled in some way.  Many functions inside CMS made simple will not operate properly without this ability. Continuing is not possible.';
$lang['test_create_dir_and_file'] = 'Checking if the httpd process can create a file inside of a directory it created.';
$lang['cms_site'] = 'CMS Svetainė';
$lang['or_greater'] = 'Ar didesnė';
$lang['sitename'] = 'Svetainės pavadinimas';
$lang['warning_safe_mode'] = '<strong><em>Įspėjimas:</em></strong> PHP Safe mode įjungta.  Tai sukels sunkumų įkeliant bylas naudojant nar&scaron;yklę, vazdus, XML paketus. Rekomenduojame susisiekti su serverio administratoriumi, kad i&scaron;jungtų mode.';
$lang['test'] = 'Testas';
$lang['results'] = 'Rezultatai';
$lang['untested'] = 'Netestuota';
$lang['owner'] = 'Savininkas';
$lang['permissions'] = 'Leidimai (teisės)';
$lang['off'] = 'I&scaron;jungti';
$lang['on'] = 'Įjungti';
$lang['permission_information'] = 'Leidimų informacija';
$lang['server_os'] = 'Serverio Opercinė sistema';
$lang['server_api'] = 'Serverio API';
$lang['server_software'] = 'Serverio Programinė įranga';
$lang['server_information'] = 'Serverio Informacija';
$lang['session_save_path'] = 'Session Save Path';
$lang['max_execution_time'] = 'Maximum Execution Time';
$lang['gd_version'] = 'GD versija';
$lang['upload_max_filesize'] = 'Maksimalus atsiuntimo dydis';
$lang['post_max_size'] = 'Maksimalus Įra&scaron;o dydis';
$lang['memory_limit'] = 'PHP Atminities Limitas';
$lang['server_db_type'] = 'Serverio Duomenų bazė';
$lang['server_db_version'] = 'Serverio Duomenų bazės versija';
$lang['phpversion'] = 'Dabartinė PHP Versija';
$lang['safe_mode'] = 'PHP Safe Mode';
$lang['php_information'] = 'PHP Informacija';
$lang['cms_install_information'] = 'CMS Įdiegimo informacija';
$lang['cms_version'] = 'CMS Versija';
$lang['systeminfo_copy_paste'] = 'Pra&scaron;ome nukopijuoti &scaron;į tekstą į forumo prane&scaron;imą';
$lang['help_systeminformation'] = 'The information displayed below is collected from a variety of locations, and summarized here so that you may be able to conveniently find some of the information required when trying to diagnose a problem or request help with your CMS Made Simple installation.';
$lang['systeminfo'] = 'Sistemos Informacija';
$lang['systeminfodescription'] = 'Display various pieces of information about your system that may be useful in diagnosing problems';
$lang['error'] = 'Klaida';
$lang['new_version_available'] = '<em>Atminkite:</em> Naujesnė CMS Made Simple versija galima. Pra&scaron;ome prane&scaron;ti apie tai jūsų administratoriui';
$lang['info_urlcheckversion'] = 'Jei adresas yra &quot;none&quot; patirkinimas nebus atliekamas.<br/> Tu&scaron;čia eilutė naudojama rezultatams nutylėtiems URL';
$lang['urlcheckversion'] = 'Patikrinti naują CMS versiją naudojant &scaron;į URL';
$lang['read'] = 'Skaityti';
$lang['write'] = 'Ra&scaron;yti';
$lang['execute'] = '&Scaron;alinti';
$lang['group'] = 'Grupei';
$lang['other'] = 'Kitiems';
$lang['global_umask'] = 'Bylų kūrimo kaukė (Mask (umask))';
$lang['errorcantcreatefile'] = 'Nįmanoma sukurti bylos (leidimų problemos?)';
$lang['add'] = 'Pridėti';
$lang['about'] = 'Apie';
$lang['action'] = 'Veiksmas';
$lang['actionstatus'] = 'Veiksmas/Būsena';
$lang['active'] = 'Aktyvus';
$lang['cantremove'] = 'Negalima pa&scaron;alinti';
$lang['changepermissions'] = 'Pakeisti teises';
$lang['changepermissionsconfirm'] = 'USE CAUTION\n\nThis action will attempt to ensure that all of the files making up the module are writable by the web server.\nAre you sure you want to continue?';
$lang['success'] = 'Įvykdyta sėkmingai';
$lang['advanced'] = 'Detaliau';
$lang['back'] = 'Atgal į meniu';
$lang['cancel'] = 'At&scaron;aukti';
$lang['cantchmodfiles'] = 'Nepavyko pakeisti kai kurių failų teisių';
$lang['cantremovefiles'] = 'Problema &scaron;alinant failus (teisių problema?)';
$lang['create'] = 'Sukurti';
$lang['database'] = 'Duomenų bazė';
$lang['databaseprefix'] = 'Duomenų bazės prie&scaron;dėlis';
$lang['databasetype'] = 'Duomenų bazės tipas';
$lang['date'] = 'Data';
$lang['default'] = 'Pagal nutylėjimą';
$lang['delete'] = '&Scaron;alinti';
$lang['deleteconfirm'] = 'Ar tikrai norite i&scaron;trinti - %s - ?';
$lang['description'] = 'Apra&scaron;ymas';
$lang['directoryexists'] = 'Toks katalogas jau egzistuota.';
$lang['down'] = 'Žemyn';
$lang['edit'] = 'Redaguoti';
$lang['email'] = 'El. pa&scaron;to adresas';
$lang['errordeletingfile'] = 'Nepavyko i&scaron;trinti bylos. Leidimų (teisių) problema?';
$lang['errordirectorynotwritable'] = 'Nėra leidimo ra&scaron;yti į katalogą. Tai gali būt jei nesuteikti leidimai ar savininkas. Safe mode taip pat gali paveikti.';
$lang['cachenotwritable'] = 'Cache katalogas neįra&scaron;omas. Laikinosios atminties valymas neveiks. Pra&scaron;ome tmp/cache katalgui suteikti skaitymo/ra&scaron;ymo/trynimo teises  (chmod 777).  Safe mode taip pat gali paveikti.';
$lang['modulesnotwritable'] = 'Modulių katalogas neįra&scaron;omas, jei norėsite įdiegti modulius atsiųsdami juos XML byloje reikia, kad modulių katalogas turėtų skaitymo/ra&scaron;ymo/trynimo teises  (chmod 777).  Safe mode taip pat gali paveikti.';
$lang['false'] = 'Ne';
$lang['settrue'] = 'Nustatyti į teigiamą';
$lang['filename'] = 'Bylos pavadinimas';
$lang['filesize'] = 'Bylos dydis';
$lang['help'] = 'Pagalba';
$lang['language'] = 'Kalba';
$lang['lastname'] = 'Pavardė';
$lang['name'] = 'Vardas';
$lang['password'] = 'Slaptažodis';
$lang['passwordagain'] = 'Slaptažodis (pakartoti)';
$lang['remove'] = 'Pa&scaron;alinti';
$lang['saveconfig'] = 'I&scaron;saugoti nustatymus';
$lang['true'] = 'Taip';
$lang['setfalse'] = 'Nustatyti į neigiamą';
$lang['type'] = 'Tipas';
$lang['typenotvalid'] = 'Netinkamas tipas';
$lang['unknown'] = 'Nežinomas';
$lang['user'] = 'Vartotojas';
$lang['userdefinedtags'] = 'Vartotojo apra&scaron;ytos žymės (Tags)';
$lang['usermanagement'] = 'Vartotojų valdymas';
$lang['username'] = 'Vartotojo vardas';
$lang['usernameincorrect'] = 'Vartotojo vardas arba slaptažodis neteisingi';
$lang['version'] = 'Versija';
$lang['install_title'] = 'CMS Made Simple Įdiegimas (žingsnis %s)';
$lang['install_system'] = 'Įdiegti sistemą';
$lang['install_thanks'] = 'Dėkojame, kad pasirinkote CMS Made Simple';
$lang['upgrade_title'] = 'CMS Made Simple Upgrade (step %s)';
$lang['upgrade_system'] = 'Upgrade System';
$lang['upgrade_thanks'] = 'Thanks for upgrading CMS Made Simple to';
$lang['install_please_read'] = 'Please read the <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">Installation Troubleshooting</a> page in the CMS Made Simple Documentation Wiki.';
$lang['install_checking'] = 'Tikrinamami leidimai ir PHP nuostatos';
$lang['install_test'] = 'Testas';
$lang['install_result'] = 'Rezultatas';
$lang['install_required_settings'] = 'Būtina nuostata';
$lang['install_recommended_settings'] = 'Rekomenduojama nuostata';
$lang['install_you_have'] = 'Jūs turite';
$lang['install_legend'] = 'Legenda';
$lang['install_symbol'] = 'Simbolis';
$lang['install_definition'] = 'Apibrėžimas';
$lang['install_value_passed'] = 'Privalomas testas pavyko';
$lang['install_value_failed'] = 'Privalomas testas nepavyko';
$lang['install_error_fragment'] = 'Info Installation Troubleshooting';
$lang['install_value_required'] = 'Nuostata yra žemiau privalomos reik&scaron;mės';
$lang['install_value_recommended'] = 'Nuostatos reik&scaron;mė yra auk&scaron;čiau privalomos, bet žemiau rekomenduojamos reik&scaron;mės<br /> arba.. kai kurios galimybės negalimos.';
$lang['install_value_exceed'] = 'Nuostatos atitinka ar vir&scaron;ija rekomenduojama slenkstį<br /> arba.. kai kurios galimybės negalimos.
';
$lang['install_test_failed'] = 'Vienas ar keli testai nepavyko. Jūs vis dar galite įdiegti sistemą bet kai kurios funkcijos neveiks teisinga.<br />Pra&scaron;ome i&scaron;taisyti klaidas ir paspausti &quot;Bandyti dar kartą&quot;, arba spauskite Tęsti mygtuką.';
$lang['install_test_passed'] = 'Visi testai pavyko (bent jau minimaliai). Pra&scaron;ome spausti &quot;Tęsti&quot; mygtuką.';
$lang['install_failed_again'] = 'Vienas ar keli testai nepavyko. Pra&scaron;ome i&scaron;taisyti problemas ir spausti mygtuką esanti žemiau. ';
$lang['install_try_again'] = 'Bandyti dar kartą';
$lang['install_continue'] = 'Tęsti';
$lang['failure'] = 'Nesėkmė';
$lang['caution'] = 'Perspėjimas';
$lang['install_admin_umask'] = 'I&scaron;bandyti Bylų kūrimo kaukę (Mask)';
$lang['install_test_umask'] = 'Pra&scaron;ome spausti Bandyti mygtuką  ..............................';
$lang['test_umask_text'] = 'umask (abbreviated from user file creation mode mask) is a function in POSIX environments which affects the default file system mode for newly created files and directories of the current process. It controls which of the file permissions will not be set for any newly created file.';
$lang['test_check_umask'] = 'Testo rezultatai bylos kūrimas';
$lang['test_umask_not_given'] = 'Umask not given';
$lang['test_check_umask_failed'] = 'Test umask failed';
$lang['test_username_not_given'] = 'Vartotojo vardo trūksta!';
$lang['test_username_illegal'] = 'Vartotojo vardas sudarytas i&scaron; neleistinų simbolių!';
$lang['test_not_both_passwd'] = 'Neįvestas nei vienas slaptažodis!';
$lang['test_passwd_not_match'] = 'Slaptažodžiai nesutampa!';
$lang['test_email_accountinfo'] = 'Siųsti informacija pasirinkta, bet neįra&scaron;ytas el. pa&scaron;to adresas!';
$lang['test_database_prefix'] = 'Duomenų bazės prie&scaron;dėlis sudarytas i&scaron; neleistinų simbolių';
$lang['test_no_dbms'] = 'Nepasirinkta dbms!';
$lang['test_could_not_connect_db'] = 'Neįmanoma prisijungti prie duomenų bazės. Patikrinkite ar prisijungimo vardas ir slaptažodžiai teisingi.';
$lang['test_could_not_drop_table'] = 'Neįmanoma i&scaron;mesti lentelių. Patikrinkite ar duomenų bazė turi atitinkamus leidimus.';
$lang['test_could_not_create_table'] = 'Neįmanoma sukurtilentelių. Patikrinkite ar duomenų bazė turi atitinkamus leidimus.';
$lang['test_check_php'] = 'Tikrinama PHP versija %s+';
$lang['test_min_recommend'] = '(minimum %s, rekomenduojama %s ar didesnė)';
$lang['test_min_recommend_plus'] = '(min %s, rekomenduojama %s+)';
$lang['test_requires_php_version'] = 'CMS Made Simple reikalauja 4.3 ar didesnės (jūs turite %s), bet PHP %s ar didesnė rekomenduojama, kad i&scaron;naudoti visas sistemos ir plėtinių galimybes';
$lang['test_check_md5_func'] = 'Tikrinama md5 Funkcija';
$lang['test_check_safe_mode'] = 'Tikrinama safe mode';
$lang['test_check_safe_mode_failed'] = 'PHP safe mode gali sukelti problemų bylų atsiuntimui ir kitoms funkcijoms. Viskas priklauso nuo to ar griežtos safe mode nuostatos.';
$lang['test_check_tokenizer'] = 'Tikrinama tokenizer funkcijos';
$lang['test_check_tokenizer_failed'] = 'Not having the tokenizer could cause pages to render as purely white. We required you have this installed.';
$lang['test_check_gd'] = 'Tikrinama  GD biblioteka';
$lang['test_check_gd_failed'] = 'GD biblioteka yra privaloma kai kuriems moduliams ir funkcijosm.';
$lang['test_check_write'] = 'Tikrinama  ra&scaron;ymo teisė';
$lang['test_may_not_exist'] = '&Scaron;i byla dar gali neegzistuoti. Jei tai nėra, jums reiktų sukurti tusčią bylą su &scaron;iuo pavadinimu. Taip pat pra&scaron;ome suteikti ra&scaron;ymo teises.';
$lang['could_not_retrieve_a_value'] = 'Negalėjo atkurti vertės.... praeinančios bet kaip.';
$lang['displaying_the_value_originally'] = '<br />Displaying the value originally set in the config file (this may not be accurate).';
$lang['test_check_xml_func'] = 'Checking for basic XML (expat) support';
$lang['test_check_xml_failed'] = 'XML support is not compiled into your php install. You can still use the system, but will not be able to use any of the remote module installation functions.';
$lang['test_allow_url_fopen_failed'] = 'When allow url fopen is disabled you will not be able to accessing URL object like file using the ftp or http protocol.';
$lang['test_remote_url'] = 'Test for remote URL';
$lang['test_remote_url_failed'] = 'You will probably not be able to open a file on a remote web server.';
$lang['connection_error'] = 'Outgoing http connections do not appear to work! There is a firewall or some ACL for external connections?. This will result in module manager, and potentially other functionality failing.';
$lang['remote_connection_timeout'] = 'Connection Timed Out!';
$lang['search_string_find'] = 'Connection ok!';
$lang['connection_failed'] = 'Connection failed!';
$lang['remote_response_ok'] = 'Remote response: ok!';
$lang['remote_response_404'] = 'Remote response: not found!';
$lang['remote_response_error'] = 'Remote response: error!';
$lang['test_check_file_upload'] = 'Tikrinamas bylų atsiuntimas';
$lang['test_check_file_failed'] = 'Kai bylų atsiuntimas i&scaron;jungtas jūs negalėsite atsiųsti jokios bylos į CMS Made Simple. Jei įmanoma &scaron;is draudimas turėtų būt panaikintas, kad galėtmėte tinkamai naudotis sistemos galimybėmis. ';
$lang['test_check_memory'] = 'Checking PHP memory limit';
$lang['test_check_memory_failed'] = 'You may not have enough memory to run CMSMS correctly, or with all of your desired addons. If possible, you should try to get your system admin to raise this value. Proceed with caution.';
$lang['test_check_time_limit'] = 'Checking PHP time limit in second';
$lang['test_check_time_limit_failed'] = 'Number of seconds a script is allowed to run. If this is reached, the script returns a fatal error.';
$lang['test_check_post_max'] = 'Checking max post size';
$lang['test_check_post_max_failed'] = 'You will probably not be able to submit (larger) data. Please be aware of this restriction.';
$lang['test_check_upload_max'] = 'Checking max upload file size';
$lang['test_check_upload_max_failed'] = 'You will probably not be able to upload (larger) files using the included file management functions. Please be aware of this restriction.';
$lang['test_check_writable'] = 'Checking if %s is writable';
$lang['test_check_upload_failed'] = 'The uploads folder is not writable. You can still install the system, but you will not be able to upload files via the Admin Panel.';
$lang['test_check_images_failed'] = 'The images folder is not writable. You can still install the system, but you will not be able to upload and use images via the Admin Panel.';
$lang['test_check_modules_failed'] = 'The modules folder is not writable. You can still install the system, but you will not be able to upload modules via the Admin Panel.';
$lang['test_check_file_get_contents'] = 'Checking for file_get_contents';
$lang['test_check_file_get_contents_failed'] = 'You will probably not be able to use any of functionality that uses this function';
$lang['test_check_session_save_path'] = 'Checking if session.save_path is writable';
$lang['test_empty_session_save_path'] = 'Your session.save_path is empty. PHP will use the temporary directory of your OS. If you have SESSION problems and ini_set works you can try to enable session cookies adding: ini_set(&#039;session.use_only_cookies&#039;, 1);  to top of include.php';
$lang['test_check_session_save_path_failed'] = 'Your session.save_path is &quot;%s&quot;. Not having this as writable may make logins to the Admin Panel not work. You may want to look into making this path writable if you have trouble logging into the Admin Panel. This test may fail if safe_mode is enabled (see below).';
$lang['test_check_ini_set'] = 'Checking if ini_set works';
$lang['test_check_ini_set_failed'] = 'Although the ability to override php ini settings is not mandatory, some addon (optional) functionality uses ini_set to extend timeouts, and allow uploading of larger files, etc. You may have difficulty with some addon functionality without this capability. This test may fail if safe_mode is enabled (see below).';
$lang['install_admin_header'] = 'Admin Account Information';
$lang['install_admin_info'] = 'Select the username, password and email address for your admin account. Please make sure you record this password somewhere, as there will be no other way to login to your CMS Made Simple admin system without it.';
$lang['install_admin_email'] = 'E-mail Address';
$lang['install_admin_email_info'] = 'E-Mail Account Information';
$lang['install_admin_email_note'] = '<strong>Note:</strong> This function uses the php&#039;s mail function. If you don&#039;t receive this email, it may be an indication that your server is not properly configured and that you should contact your host administrator.';
$lang['install_admin_sitename'] = 'This is the name of your site. It will be used in various places of the default templates and can be used anywhere with the	{sitename} tag.';
$lang['install_admin_db'] = 'Database Information';
$lang['install_admin_db_info'] = '<p>Make sure you have created your database and granted full privileges to a user to use that database.</p>
<p>For MySQL, use the following:</p>
<p>Log in to mysql from a console and run the following commands:</p>
<ol>
<li>create database cms; (use whatever name you want here but make sure to remember it, you&#039;ll need to enter it on this page)</li>
<li>grant all privileges on cms.* to cms_user@localhost identified by &#039;cms_pass&#039;;</li>
</ol>';
$lang['install_admin_follow'] = 'Pra&scaron;ome užpildyti &scaron;iuos laukelius';
$lang['install_admin_db_type'] = 'Duomenų bazės tipas';
$lang['install_admin_no_db'] = 'No valid database drivers appear to be compiled into your PHP install. Please confirm that you have mysql, mysqli, and/or postgres7 support installed, and try again.';
$lang['install_admin_db_host'] = 'Duomenų bazės adresas';
$lang['install_admin_db_name'] = 'Duomenų bazės pavadinimas';
$lang['install_admin_db_create'] = 'Sukurti lenteles (Įspėjimas: Bus pa&scaron;alinti duomenys)';
$lang['install_admin_db_prefix'] = 'Lentelių prie&scaron;dėliai';
$lang['install_admin_db_sample'] = 'Įdeigti turinio ir &scaron;ablono pavyzdžius';
$lang['retry'] = 'Pakartoti';
$lang['install_admin_db_create_seq'] = 'Kuriama %s lentelių seka ...';
$lang['install_admin_importing'] = 'Importuojami pavyzdiniai duomenys...';
$lang['invalid_query'] = 'Klaidinga užklausa: %s';
$lang['install_creating_table'] = '<p>Kuriama %s lentalė... [%s]</p>';
$lang['install_creating_index'] = '<p>Kuriamas index  %s lentalėje... [%s]</p>';
$lang['done'] = 'atlikta';
$lang['failed'] = 'nepavyko';
$lang['install_admin_error_schema'] = 'Klaida SQL schemoje';
$lang['install_admin_set_account'] = 'Nustatoma administratoriaus sąskaitos informacija...';
$lang['install_admin_set_sitename'] = 'Nustatomas svetainės pavadinimas...';
$lang['install_admin_setup'] = 'Dabar tęskime į sąranką jūsų konfigūracijos bylą, mes jau turime didžiąją dalį medžiagos, kurios mums reikia. Galimybės yra jūs, gali neliesti visų &scaron;itų verčių, taip, kai jūs esate pasiruo&scaron;ęs, spauskite Tęsti.';
$lang['install_admin_docroot'] = 'CMS Document root (as seen from the webserver)';
$lang['install_admin_docroot_path'] = 'Path to the Document root';
$lang['install_admin_querystring'] = 'Query string (leave this alone unless you have trouble, then edit config.php by hand)';
$lang['invalid_querys'] = '<b>WARNING<b/>: Invalid queries on your DB!';
$lang['install_admin_sitedown'] = 'Klaida: Neįmanoma pa&scaron;alinti tmp/cache/SITEDOWN bylos. Pra&scaron;ome pa&scaron;alinti patiems.';
$lang['install_admin_update_hierarchy'] = 'Updating hierarchy positions...';
$lang['install_admin_set_core_event'] = 'Nustatomi &scaron;erdies įvykiai...';
$lang['install_admin_install_modules'] = 'Įdiegiami moduliai...';
$lang['install_admin_index_search'] = 'Index Search...';
$lang['install_admin_clear_cache'] = 'Valoma laikinoji atmintis (jei yra)...';
$lang['install_admin_emailing'] = 'Siunčiama administratoriaus paskyros informacija...';
$lang['install_admin_congratulations'] = 'Sveikiname, jūs jau įdiegėte - &scaron;tai jūsų';
$lang['could_not_connect_db'] = 'Neįmanoma prisijungti prie duomenų bazės. Patikrinkite ar prisijungimo vardas ir slaptažodis teisingi ir turi tinkamus leidimus.
';
$lang['cannot_write_config'] = 'Klaida: Neįmanoma įra&scaron;yti %s.';
$lang['email_accountinfo_subject'] = 'CMS Made Simple Administratoriaus paskyros informacija';
$lang['email_accountinfo_message'] = 'Dėkojame, kad įdiegėte CMS Made Simple.

Čia jūsų naujos paskyros duomenys:
prisijungimo vardas: %s
slaptažodis: %s
Prisijungti galite čia: %s';
$lang['utmz'] = '156861353.1250297380.1752.42.utmccn=(referral)|utmcsr=helminsen.no|utmcct=/install/upgrade.php|utmcmd=referral';
$lang['utma'] = '156861353.179052623084110100.1210423577.1259353230.1259355475.2152';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.2.10.1259355475';
?>